@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.redis_v1.types import cloud_redis
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import CloudRedisTransport, DEFAULT_CLIENT_INFO
 from .grpc import CloudRedisGrpcTransport
 
@@ -75,7 +72,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     def create_channel(
         cls,
         host: str = "redis.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -83,7 +80,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     ) -> aio.Channel:
         """Create and return a gRPC AsyncIO channel object.
         Args:
-            address (Optional[str]): The host for the channel to use.
+            host (Optional[str]): The host for the channel to use.
             credentials (Optional[~.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify this application to the service. If
@@ -102,13 +99,15 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -116,20 +115,22 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
         self,
         *,
         host: str = "redis.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
         api_mtls_endpoint: str = None,
         client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
         ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -154,12 +155,16 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                 for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
+                A callback to provide client certificate bytes and private key bytes,
+                both in PEM format. It is used to configure mutual TLS channel. It is
+                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
 
         Raises:
@@ -168,91 +173,69 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
           google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
+        self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
+        self._stubs: Dict[str, Callable] = {}
+        self._operations_client = None
+
+        if api_mtls_endpoint:
+            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
+        if client_cert_source:
+            warnings.warn("client_cert_source is deprecated", DeprecationWarning)
 
         if channel:
-            # Sanity check: Ensure that channel and credentials are not both
-            # provided.
+            # Ignore credentials if a channel was passed.
             credentials = False
-
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-        elif api_mtls_endpoint:
-            warnings.warn(
-                "api_mtls_endpoint and client_cert_source are deprecated",
-                DeprecationWarning,
-            )
-
-            host = (
-                api_mtls_endpoint
-                if ":" in api_mtls_endpoint
-                else api_mtls_endpoint + ":443"
-            )
-
-            if credentials is None:
-                credentials, _ = auth.default(
-                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
-                )
-
-            # Create SSL credentials with client_cert_source or application
-            # default SSL credentials.
-            if client_cert_source:
-                cert, key = client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
-            else:
-                ssl_credentials = SslCredentials().ssl_credentials
-
-            # create a new channel. The provided one is ignored.
-            self._grpc_channel = type(self).create_channel(
-                host,
-                credentials=credentials,
-                credentials_file=credentials_file,
-                ssl_credentials=ssl_credentials,
-                scopes=scopes or self.AUTH_SCOPES,
-                quota_project_id=quota_project_id,
-                options=[
-                    ("grpc.max_send_message_length", -1),
-                    ("grpc.max_receive_message_length", -1),
-                ],
-            )
-            self._ssl_channel_credentials = ssl_credentials
         else:
-            host = host if ":" in host else host + ":443"
+            if api_mtls_endpoint:
+                host = api_mtls_endpoint
 
-            if credentials is None:
-                credentials, _ = auth.default(
-                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
-                )
+                # Create SSL credentials with client_cert_source or application
+                # default SSL credentials.
+                if client_cert_source:
+                    cert, key = client_cert_source()
+                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
+                        certificate_chain=cert, private_key=key
+                    )
+                else:
+                    self._ssl_channel_credentials = SslCredentials().ssl_credentials
 
-            # create a new channel. The provided one is ignored.
-            self._grpc_channel = type(self).create_channel(
-                host,
-                credentials=credentials,
-                credentials_file=credentials_file,
-                ssl_credentials=ssl_channel_credentials,
-                scopes=scopes or self.AUTH_SCOPES,
-                quota_project_id=quota_project_id,
-                options=[
-                    ("grpc.max_send_message_length", -1),
-                    ("grpc.max_receive_message_length", -1),
-                ],
-            )
+            else:
+                if client_cert_source_for_mtls and not ssl_channel_credentials:
+                    cert, key = client_cert_source_for_mtls()
+                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
+                        certificate_chain=cert, private_key=key
+                    )
 
-        # Run the base constructor.
+        # The base transport sets the host, credentials and scopes
         super().__init__(
             host=host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes or self.AUTH_SCOPES,
+            scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
         )
 
-        self._stubs = {}
-        self._operations_client = None
+        if not self._grpc_channel:
+            self._grpc_channel = type(self).create_channel(
+                self._host,
+                credentials=self._credentials,
+                credentials_file=credentials_file,
+                scopes=self._scopes,
+                ssl_credentials=self._ssl_channel_credentials,
+                quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
+            )
+
+        # Wrap messages. This must be done after self._grpc_channel exists
+        self._prep_wrapped_messages(client_info)
 
     @property
     def grpc_channel(self) -> aio.Channel:
@@ -346,7 +329,9 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     @property
     def create_instance(
         self,
-    ) -> Callable[[cloud_redis.CreateInstanceRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [cloud_redis.CreateInstanceRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the create instance method over gRPC.
 
         Creates a Redis instance based on the specified tier and memory
@@ -378,14 +363,16 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["create_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/CreateInstance",
                 request_serializer=cloud_redis.CreateInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_instance"]
 
     @property
     def update_instance(
         self,
-    ) -> Callable[[cloud_redis.UpdateInstanceRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [cloud_redis.UpdateInstanceRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the update instance method over gRPC.
 
         Updates the metadata and configuration of a specific
@@ -409,7 +396,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["update_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/UpdateInstance",
                 request_serializer=cloud_redis.UpdateInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_instance"]
 
@@ -417,7 +404,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     def upgrade_instance(
         self,
     ) -> Callable[
-        [cloud_redis.UpgradeInstanceRequest], Awaitable[operations.Operation]
+        [cloud_redis.UpgradeInstanceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the upgrade instance method over gRPC.
 
@@ -438,14 +425,16 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["upgrade_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/UpgradeInstance",
                 request_serializer=cloud_redis.UpgradeInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["upgrade_instance"]
 
     @property
     def import_instance(
         self,
-    ) -> Callable[[cloud_redis.ImportInstanceRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [cloud_redis.ImportInstanceRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the import instance method over gRPC.
 
         Import a Redis RDB snapshot file from Cloud Storage
@@ -472,14 +461,16 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["import_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/ImportInstance",
                 request_serializer=cloud_redis.ImportInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["import_instance"]
 
     @property
     def export_instance(
         self,
-    ) -> Callable[[cloud_redis.ExportInstanceRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [cloud_redis.ExportInstanceRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the export instance method over gRPC.
 
         Export Redis instance data into a Redis RDB format
@@ -502,7 +493,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["export_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/ExportInstance",
                 request_serializer=cloud_redis.ExportInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["export_instance"]
 
@@ -510,7 +501,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     def failover_instance(
         self,
     ) -> Callable[
-        [cloud_redis.FailoverInstanceRequest], Awaitable[operations.Operation]
+        [cloud_redis.FailoverInstanceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the failover instance method over gRPC.
 
@@ -532,14 +523,16 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["failover_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/FailoverInstance",
                 request_serializer=cloud_redis.FailoverInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["failover_instance"]
 
     @property
     def delete_instance(
         self,
-    ) -> Callable[[cloud_redis.DeleteInstanceRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [cloud_redis.DeleteInstanceRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the delete instance method over gRPC.
 
         Deletes a specific Redis instance.  Instance stops
@@ -559,7 +552,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             self._stubs["delete_instance"] = self.grpc_channel.unary_unary(
                 "/google.cloud.redis.v1.CloudRedis/DeleteInstance",
                 request_serializer=cloud_redis.DeleteInstanceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_instance"]
 
