@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-import builtins
 from collections import OrderedDict
 import functools
 import re
@@ -23,21 +20,20 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.redis_v1beta1.services.cloud_redis import pagers
 from google.cloud.redis_v1beta1.types import cloud_redis
-from google.protobuf import any_pb2 as gp_any  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import any_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import CloudRedisTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import CloudRedisGrpcAsyncIOTransport
 from .client import CloudRedisClient
@@ -74,36 +70,61 @@ class CloudRedisAsyncClient:
 
     instance_path = staticmethod(CloudRedisClient.instance_path)
     parse_instance_path = staticmethod(CloudRedisClient.parse_instance_path)
-
     common_billing_account_path = staticmethod(
         CloudRedisClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         CloudRedisClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(CloudRedisClient.common_folder_path)
     parse_common_folder_path = staticmethod(CloudRedisClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(CloudRedisClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         CloudRedisClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(CloudRedisClient.common_project_path)
     parse_common_project_path = staticmethod(CloudRedisClient.parse_common_project_path)
-
     common_location_path = staticmethod(CloudRedisClient.common_location_path)
     parse_common_location_path = staticmethod(
         CloudRedisClient.parse_common_location_path
     )
 
-    from_service_account_file = CloudRedisClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudRedisAsyncClient: The constructed client.
+        """
+        return CloudRedisClient.from_service_account_info.__func__(CloudRedisAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudRedisAsyncClient: The constructed client.
+        """
+        return CloudRedisClient.from_service_account_file.__func__(CloudRedisAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> CloudRedisTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             CloudRedisTransport: The transport used by the client instance.
@@ -117,12 +138,12 @@ class CloudRedisAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, CloudRedisTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the cloud redis client.
+        """Instantiates the cloud redis client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -154,7 +175,6 @@ class CloudRedisAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = CloudRedisClient(
             credentials=credentials,
             transport=transport,
@@ -183,7 +203,7 @@ class CloudRedisAsyncClient:
         are aggregated.
 
         Args:
-            request (:class:`~.cloud_redis.ListInstancesRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.ListInstancesRequest`):
                 The request object. Request for
                 [ListInstances][google.cloud.redis.v1beta1.CloudRedis.ListInstances].
             parent (:class:`str`):
@@ -191,10 +211,10 @@ class CloudRedisAsyncClient:
                 using the form:
                 ``projects/{project_id}/locations/{location_id}`` where
                 ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -202,7 +222,7 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListInstancesAsyncPager:
+            google.cloud.redis_v1beta1.services.cloud_redis.pagers.ListInstancesAsyncPager:
                 Response for
                 [ListInstances][google.cloud.redis.v1beta1.CloudRedis.ListInstances].
 
@@ -213,7 +233,7 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([parent])
+        has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -224,7 +244,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -266,17 +285,17 @@ class CloudRedisAsyncClient:
         r"""Gets the details of a specific Redis instance.
 
         Args:
-            request (:class:`~.cloud_redis.GetInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.GetInstanceRequest`):
                 The request object. Request for
                 [GetInstance][google.cloud.redis.v1beta1.CloudRedis.GetInstance].
             name (:class:`str`):
                 Required. Redis instance resource name using the form:
                 ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
                 where ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -284,13 +303,13 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloud_redis.Instance:
+            google.cloud.redis_v1beta1.types.Instance:
                 A Google Cloud Redis instance.
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([name])
+        has_flattened_params = any([name])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -301,7 +320,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -352,7 +370,7 @@ class CloudRedisAsyncClient:
         hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`~.cloud_redis.CreateInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.CreateInstanceRequest`):
                 The request object. Request for
                 [CreateInstance][google.cloud.redis.v1beta1.CloudRedis.CreateInstance].
             parent (:class:`str`):
@@ -360,6 +378,7 @@ class CloudRedisAsyncClient:
                 using the form:
                 ``projects/{project_id}/locations/{location_id}`` where
                 ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -373,15 +392,15 @@ class CloudRedisAsyncClient:
                 -  Must be between 1-40 characters.
                 -  Must end with a number or a letter.
                 -  Must be unique within the customer project / location
+
                 This corresponds to the ``instance_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            instance (:class:`~.cloud_redis.Instance`):
+            instance (:class:`google.cloud.redis_v1beta1.types.Instance`):
                 Required. A Redis [Instance] resource
                 This corresponds to the ``instance`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -389,18 +408,18 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloud_redis.Instance``: A Google Cloud Redis
-                instance.
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([parent, instance_id, instance])
+        has_flattened_params = any([parent, instance_id, instance])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -411,7 +430,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if instance_id is not None:
@@ -441,7 +459,7 @@ class CloudRedisAsyncClient:
             response,
             self._client._transport.operations_client,
             cloud_redis.Instance,
-            metadata_type=gp_any.Any,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
@@ -451,7 +469,7 @@ class CloudRedisAsyncClient:
         self,
         request: cloud_redis.UpdateInstanceRequest = None,
         *,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         instance: cloud_redis.Instance = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -465,10 +483,10 @@ class CloudRedisAsyncClient:
         there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`~.cloud_redis.UpdateInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.UpdateInstanceRequest`):
                 The request object. Request for
                 [UpdateInstance][google.cloud.redis.v1beta1.CloudRedis.UpdateInstance].
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 Required. Mask of fields to update. At least one path
                 must be supplied in this field. The elements of the
                 repeated paths field may only include these fields from
@@ -478,16 +496,17 @@ class CloudRedisAsyncClient:
                 -  ``labels``
                 -  ``memorySizeGb``
                 -  ``redisConfig``
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            instance (:class:`~.cloud_redis.Instance`):
+            instance (:class:`google.cloud.redis_v1beta1.types.Instance`):
                 Required. Update description. Only fields specified in
                 update_mask are updated.
+
                 This corresponds to the ``instance`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -495,18 +514,18 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloud_redis.Instance``: A Google Cloud Redis
-                instance.
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([update_mask, instance])
+        has_flattened_params = any([update_mask, instance])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -517,7 +536,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if update_mask is not None:
             request.update_mask = update_mask
         if instance is not None:
@@ -547,7 +565,7 @@ class CloudRedisAsyncClient:
             response,
             self._client._transport.operations_client,
             cloud_redis.Instance,
-            metadata_type=gp_any.Any,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
@@ -567,23 +585,24 @@ class CloudRedisAsyncClient:
         specified in the request.
 
         Args:
-            request (:class:`~.cloud_redis.UpgradeInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.UpgradeInstanceRequest`):
                 The request object. Request for
                 [UpgradeInstance][google.cloud.redis.v1beta1.CloudRedis.UpgradeInstance].
             name (:class:`str`):
                 Required. Redis instance resource name using the form:
                 ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
                 where ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             redis_version (:class:`str`):
                 Required. Specifies the target
                 version of Redis software to upgrade to.
+
                 This corresponds to the ``redis_version`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -591,18 +610,18 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloud_redis.Instance``: A Google Cloud Redis
-                instance.
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([name, redis_version])
+        has_flattened_params = any([name, redis_version])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -613,7 +632,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if redis_version is not None:
@@ -641,7 +659,7 @@ class CloudRedisAsyncClient:
             response,
             self._client._transport.operations_client,
             cloud_redis.Instance,
-            metadata_type=gp_any.Any,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
@@ -668,23 +686,24 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`~.cloud_redis.ImportInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.ImportInstanceRequest`):
                 The request object. Request for
                 [Import][google.cloud.redis.v1beta1.CloudRedis.ImportInstance].
             name (:class:`str`):
                 Required. Redis instance resource name using the form:
                 ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
                 where ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            input_config (:class:`~.cloud_redis.InputConfig`):
+            input_config (:class:`google.cloud.redis_v1beta1.types.InputConfig`):
                 Required. Specify data to be
                 imported.
+
                 This corresponds to the ``input_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -692,18 +711,18 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloud_redis.Instance``: A Google Cloud Redis
-                instance.
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([name, input_config])
+        has_flattened_params = any([name, input_config])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -714,7 +733,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if input_config is not None:
@@ -742,7 +760,7 @@ class CloudRedisAsyncClient:
             response,
             self._client._transport.operations_client,
             cloud_redis.Instance,
-            metadata_type=gp_any.Any,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
@@ -765,23 +783,24 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`~.cloud_redis.ExportInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.ExportInstanceRequest`):
                 The request object. Request for
                 [Export][google.cloud.redis.v1beta1.CloudRedis.ExportInstance].
             name (:class:`str`):
                 Required. Redis instance resource name using the form:
                 ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
                 where ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            output_config (:class:`~.cloud_redis.OutputConfig`):
+            output_config (:class:`google.cloud.redis_v1beta1.types.OutputConfig`):
                 Required. Specify data to be
                 exported.
+
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -789,18 +808,18 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloud_redis.Instance``: A Google Cloud Redis
-                instance.
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([name, output_config])
+        has_flattened_params = any([name, output_config])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -811,7 +830,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if output_config is not None:
@@ -839,7 +857,7 @@ class CloudRedisAsyncClient:
             response,
             self._client._transport.operations_client,
             cloud_redis.Instance,
-            metadata_type=gp_any.Any,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
@@ -860,24 +878,25 @@ class CloudRedisAsyncClient:
         Memorystore for Redis instance.
 
         Args:
-            request (:class:`~.cloud_redis.FailoverInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.FailoverInstanceRequest`):
                 The request object. Request for
                 [Failover][google.cloud.redis.v1beta1.CloudRedis.FailoverInstance].
             name (:class:`str`):
                 Required. Redis instance resource name using the form:
                 ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
                 where ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            data_protection_mode (:class:`~.cloud_redis.FailoverInstanceRequest.DataProtectionMode`):
+            data_protection_mode (:class:`google.cloud.redis_v1beta1.types.FailoverInstanceRequest.DataProtectionMode`):
                 Optional. Available data protection modes that the user
                 can choose. If it's unspecified, data protection mode
                 will be LIMITED_DATA_LOSS by default.
+
                 This corresponds to the ``data_protection_mode`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -885,18 +904,18 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloud_redis.Instance``: A Google Cloud Redis
-                instance.
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([name, data_protection_mode])
+        has_flattened_params = any([name, data_protection_mode])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -907,7 +926,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if data_protection_mode is not None:
@@ -935,7 +953,7 @@ class CloudRedisAsyncClient:
             response,
             self._client._transport.operations_client,
             cloud_redis.Instance,
-            metadata_type=gp_any.Any,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
@@ -954,17 +972,17 @@ class CloudRedisAsyncClient:
         serving and data is deleted.
 
         Args:
-            request (:class:`~.cloud_redis.DeleteInstanceRequest`):
+            request (:class:`google.cloud.redis_v1beta1.types.DeleteInstanceRequest`):
                 The request object. Request for
                 [DeleteInstance][google.cloud.redis.v1beta1.CloudRedis.DeleteInstance].
             name (:class:`str`):
                 Required. Redis instance resource name using the form:
                 ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
                 where ``location_id`` refers to a GCP region.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -972,30 +990,28 @@ class CloudRedisAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = builtins.any([name])
+        has_flattened_params = any([name])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -1006,7 +1022,6 @@ class CloudRedisAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -1031,8 +1046,8 @@ class CloudRedisAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
-            metadata_type=gp_any.Any,
+            empty_pb2.Empty,
+            metadata_type=any_pb2.Any,
         )
 
         # Done; return the response.
